import java.awt.Color;
import java.awt.Graphics;
import java.net.InetAddress;
import java.net.UnknownHostException;


/**
 * @author bachmaer
 *         <p/>
 *         Maintains the state information for an AlienSpaceCraft
 */
public class AlienSpaceCraft extends SpaceCraft {

    /**
     * Creates an AlienSpaceCraft with the values of the input parameters
     *
     * @param ID      IP address associate with the ship
     * @param port    number associated with the ship
     * @param x       position of the ship
     * @param y       position of the ship
     * @param heading of the ship
     */
    public AlienSpaceCraft(InetAddress ID, int IDport, int x, int y, int heading) {
        this.ID = ID;
        this.IDport = IDport;

        this.setHeading(heading);

        this.setX(x);

        this.setY(y);

    } // end AlienCraft constructor


    /**
     * Renders the alien space craft as a red dot. A small line segment points in
     * the direction of the heading.
     *
     * @param g Graphical render context
     */
    public void draw(Graphics g) {
        int halfWidth = Constants.OBJECT_WIDTH / 2;

        // Draw the spacecraft with the appropriate heading
        g.setColor(Color.RED);

        g.fillOval(xPosition - halfWidth, yPosition - halfWidth,
                Constants.OBJECT_WIDTH, Constants.OBJECT_WIDTH);

        switch (heading) {

            case Constants.NORTH:

                g.drawLine(xPosition, yPosition - halfWidth, xPosition,
                        yPosition - Constants.OBJECT_WIDTH);
                break;
            case Constants.EAST:

                g.drawLine(xPosition + halfWidth, yPosition,
                        xPosition + Constants.OBJECT_WIDTH, yPosition);
                break;
            case Constants.SOUTH:

                g.drawLine(xPosition, yPosition + halfWidth, xPosition,
                        yPosition + Constants.OBJECT_WIDTH);
                break;
            case Constants.WEST:

                g.drawLine(xPosition - halfWidth, yPosition,
                        xPosition - Constants.OBJECT_WIDTH, yPosition);
                break;
        }

    } // end draw

    /**
     * Test main for the AlienSpaceCraft class.
     *
     * @param args
     */
    /*
        public static void main(String[] args)
        {
            AlienSpaceCraft a;
            AlienSpaceCraft b;

            try {
                a = new AlienSpaceCraft(InetAddress.getLocalHost(), 10000, 1, 1, 1);
                b = new AlienSpaceCraft(InetAddress.getLocalHost(), 10001, 1, 1, 1);

                if ( a.equals(b) ) System.out.println( "They are equal" );

            } catch (UnknownHostException e) {

                e.printStackTrace();
            }

        } // end main
    */

} // end AlienSpaceCraft class
