import java.awt.Color;
import java.awt.Graphics;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.Random;

/**
 * @author bachmaer
 *         <p/>
 *         Maintains state of the users on SpaceCraft.
 */
public class OwnSpaceCraft extends SpaceCraft {

    // Random number generator for setting random position with a random heading
    static Random rand = new Random();

    // Position change increment
    static final int INCREMENT = Constants.INCREMENT;


    /**
     * Creates OwnSpaceCraft with random position and heading.
     */
    public OwnSpaceCraft(int port) {
        try {
            this.ID = InetAddress.getLocalHost();
        } catch (UnknownHostException e) {

            e.printStackTrace();
        }

        this.IDport = port;
        this.heading = rand.nextInt(4) + 1;

        this.xPosition = rand.nextInt(Constants.MAX_SECTOR_X);

        this.yPosition = rand.nextInt(Constants.MAX_SECTOR_Y);

    } // end AlienCraft constructor


    /**
     * Move OwnsSpaceCraft ahead one increment in the direstion in which it is
     * headed. Spacecraft is stopped at the edge of the world.
     */
    public void move() {
        switch (heading) {

            case Constants.NORTH:

                yPosition = (yPosition - INCREMENT > 0) ? yPosition - INCREMENT : 0;

                break;
            case Constants.EAST:

                xPosition = (xPosition + INCREMENT < Constants.MAX_SECTOR_X)
                        ? xPosition + INCREMENT : Constants.MAX_SECTOR_X;

                break;
            case Constants.SOUTH:

                yPosition = (yPosition + INCREMENT < Constants.MAX_SECTOR_Y)
                        ? yPosition + INCREMENT : Constants.MAX_SECTOR_Y;

                break;
            case Constants.WEST:

                xPosition = (xPosition - INCREMENT > 0) ? xPosition - INCREMENT : 0;

                break;

            default:

                System.err.println("Illegal Heading");
                break;
        }

    } // end move


    /**
     * Increments the heading 90 degrees to the right.
     */
    public void rightTurn() {
        heading++;
        if (heading > Constants.WEST) heading = 1;

    } // end rightTurn


    /**
     * Increments the heading 90 degrees to the left.
     */
    public void leftTurn() {
        heading--;

        if (heading < 1) heading = Constants.WEST;

    } // end leftTurn


    /**
     * Draws the SpaceCraft in white as a arrow point oriented in the
     * heading direction.
     */
    public void draw(Graphics g) {
        int halfWidth = Constants.OBJECT_WIDTH / 2;

        // Draw the spacecraft with the appropriate heading
        g.setColor(Color.WHITE);
        switch (heading) {

            case Constants.NORTH:

                g.drawLine(xPosition, yPosition - halfWidth, xPosition - halfWidth,
                        yPosition + halfWidth);
                g.drawLine(xPosition, yPosition - halfWidth, xPosition + halfWidth,
                        yPosition + halfWidth);

                break;
            case Constants.EAST:

                g.drawLine(xPosition + halfWidth, yPosition, xPosition - halfWidth,
                        yPosition + halfWidth);
                g.drawLine(xPosition + halfWidth, yPosition, xPosition - halfWidth,
                        yPosition - halfWidth);

                break;
            case Constants.SOUTH:

                g.drawLine(xPosition, yPosition + halfWidth, xPosition - halfWidth,
                        yPosition - halfWidth);
                g.drawLine(xPosition, yPosition + halfWidth, xPosition + halfWidth,
                        yPosition - halfWidth);

                break;
            case Constants.WEST:

                g.drawLine(xPosition - halfWidth, yPosition, xPosition + halfWidth,
                        yPosition + halfWidth);
                g.drawLine(xPosition - halfWidth, yPosition, xPosition + halfWidth,
                        yPosition - halfWidth);
                break;
        }
    } // end draw


} // end OwnSpaceCraft class
